From: Pi-Hsun Shih <pih...@chromium.org>

[ Upstream commit d178770d8d21489abf5bafefcbb6d5243b482e9a ]

Currently the basepath is removed only from the beginning of the string.
When the symbol is inlined and there's multiple line outputs of
addr2line, only the first line would have basepath removed.

Change to remove the basepath prefix from all lines.

Fixes: 31013836a71e ("scripts/decode_stacktrace: match basepath using shell 
prefix operator, not regex")
Co-developed-by: Shik Chen <s...@chromium.org>
Signed-off-by: Pi-Hsun Shih <pih...@chromium.org>
Signed-off-by: Shik Chen <s...@chromium.org>
Signed-off-by: Andrew Morton <a...@linux-foundation.org>
Reviewed-by: Stephen Boyd <swb...@chromium.org>
Cc: Sasha Levin <sas...@kernel.org>
Cc: Nicolas Boichat <drink...@chromium.org>
Cc: Jiri Slaby <jsl...@suse.cz>
Link: http://lkml.kernel.org/r/20200720082709.252805-1-pih...@chromium.org
Signed-off-by: Linus Torvalds <torva...@linux-foundation.org>
Signed-off-by: Sasha Levin <sas...@kernel.org>
---
 scripts/decode_stacktrace.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/scripts/decode_stacktrace.sh b/scripts/decode_stacktrace.sh
index 4f5e76f76b9dc..003968cb04d4a 100755
--- a/scripts/decode_stacktrace.sh
+++ b/scripts/decode_stacktrace.sh
@@ -63,8 +63,8 @@ parse_symbol() {
                return
        fi
 
-       # Strip out the base of the path
-       code=${code#$basepath/}
+       # Strip out the base of the path on each line
+       code=$(while read -r line; do echo "${line#$basepath/}"; done <<< 
"$code")
 
        # In the case of inlines, move everything to same line
        code=${code//$'\n'/' '}
-- 
2.25.1



Reply via email to